Reference
=========

:mod:`postgresql`
-----------------

.. automodule:: postgresql
.. autodata:: version
.. autodata:: version_info
.. autofunction:: open

:mod:`postgresql.api`
---------------------

.. automodule::
    postgresql.api
    :members:
    :show-inheritance:

:mod:`postgresql.sys`
---------------------

.. automodule::
    postgresql.sys
    :members:
    :show-inheritance:

:mod:`postgresql.string`
------------------------

.. automodule::
    postgresql.string
    :members:
    :show-inheritance:

:mod:`postgresql.exceptions`
----------------------------

.. automodule::
    postgresql.exceptions
    :members:
    :show-inheritance:

:mod:`postgresql.temporal`
--------------------------

.. automodule::
    postgresql.temporal
    :members:
    :show-inheritance:

:mod:`postgresql.installation`
------------------------------

.. automodule::
    postgresql.installation
    :members:
    :show-inheritance:

:mod:`postgresql.cluster`
-------------------------

.. automodule::
    postgresql.cluster
    :members:
    :show-inheritance:

:mod:`postgresql.copyman`
-------------------------

.. automodule::
    postgresql.copyman
    :members:
    :show-inheritance:

:mod:`postgresql.alock`
-----------------------

.. automodule::
    postgresql.alock
    :members:
    :show-inheritance:
